<?php
/* 
 * Copyright (C) 2012 Fructisoft (Jeremy Joly), All Rights Reserved. 
 * @license - http://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 */
 

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

class FsBrowserCompatibilityBasePlugin extends JPlugin  {

    /*
     * X-UA Compatible meta tag is used by 2 settings. Handle it separately
     */
    private $MetaXuaCompatible = array();
    
    function FsBrowserCompatibilityBasePlugin(& $subject, $config) {

        parent::__construct($subject, $config);

        // Load component settings
        $this->params = JComponentHelper::getParams('com_fsbrowsercompatibility');
         
    }
    
    
    function onAfterInitialise() {

       
        $application = JFactory::getApplication();
        $document = JFactory::getDocument();
        
        // Handle only HTML output
        if( $document->getType() != 'html' ) return;

        // Check if enabled on Frontend / Backend
        if( $application->isSite() &&  $this->params->get('EnableOnFrontend', 1) == 0 ) return;
        if( $application->isAdmin() &&  $this->params->get('EnableOnBackend', 0) == 0 ) return;
        
    

        // IE Compatibility View
        if ($this->params->get('IeEnableCompatibilityViewMode', 1) == 1)
            $this->IeCompatibilityView();

        // HTML5 Compatibility
        if ($this->params->get('IeEnableHTML5Compatibility', 1) == 1)
            $this->html5Compatibility($document);

        // Handle PNG Alpha Fix
        if ($this->params->get('IeEnablePngFix', 0) == 1)
            $this->IePngFix($document);

        // Hide Javascript errors
        if ($this->params->get('HideJavascriptErrors', 1) == 1)
            $this->HideJavascriptErrors($document);
        
        // Reset Css Default Values
        if ($this->params->get('ResetCssDefaultValues', 0) == 1)
            $this->CssReset($document);
        
        // Google Chrome Frame
        if ($this->params->get('ChromeEnableFrame', 0) == 1)
            $this->GoogleChromeFrame();
        
        // Disable Safari telephone links
        if ($this->params->get('SafariDisableTelephoneLinks', 1) == 1)
            $this->DisableSafariTelephoneLinks($document);
        
        // Set viewport for mobile devices
        if ($this->params->get('MobileSetViewport', 1) == 1)
            $this->SetViewport($document);

        // Handle X-UA Compatible meta tag
        if( count($this->MetaXuaCompatible) > 0)
            $this->HandleXuaCompatibleMetaTag($document);
        
        
    }
   
    
    function DisableSafariTelephoneLinks($document){
        $document->setMetaData('format-detection', 'telephone=no', false, true);
    }
    
    function IeCompatibilityView() {
        $this->MetaXuaCompatible[] = 'IE=EmulateIE7';
    }
    
    function GoogleChromeFrame(){
        $this->MetaXuaCompatible[] = 'chrome=1';
    }
    
    function HandleXuaCompatibleMetaTag($document){
        $document->setMetaData('X-UA-Compatible', implode(',', $this->MetaXuaCompatible), false, true);
    }
    
    function SetViewport($document){
        $document->setMetaData('viewport', 'width=device-width, initial-scale=1, maximum-scale=1', false, true);
    }
    
    function html5Compatibility($document){
        $document->_custom[] = "<!--[if lt IE 9]>\n" .
                "<script type=\"text/javascript\" src=\"plugins/system/fsbrowsercompatibility/assets/html5.js\"></script>\n" .
                "<![endif]-->"; 
    }

    function CssReset($document){
        $document->addStyleSheet(JURI::root().'plugins/system/fsbrowsercompatibility/assets/reset-min.css');
    }
    
    
    function IePngFix($document) {
        $document->_custom[] = "<!--[if lte IE 6]>\n" .
                "<script defer type=\"text/javascript\" src=\"plugins/system/fsbrowsercompatibility/assets/iepngfix.js\"></script>\n" .
                "<![endif]-->";
    }

    function HideJavascriptErrors($document) {
        $document->addScriptDeclaration("function noError(){return true;}\nwindow.onerror = noError;\n");
    }
    
    
}
